// OpenLP Mobile Remote
// ---------------------------------------------------------------------------
// Copyright (c) 2008-2019 OpenLP Developers
// ---------------------------------------------------------------------------
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';


class Settings extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _SettingState();
}

class _SettingState extends State<Settings> {
  String serverIp;
  int serverPort;
  bool useHttps;
  bool needsAuth;
  bool darkTheme;
  String userId;
  String userPassword;

  @override
  void initState() {
    super.initState();
    serverIp = '192.168.1.100';
    serverPort = 4316;
    useHttps = false;
    needsAuth = false;
    darkTheme = false;
    userId = 'openlp';
    userPassword = 'password';
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Settings'),
      ),
      body: ListView(
        children: <Widget>[
          ListTile(
            title: Text('Server IP'),
            subtitle: Text(serverIp),
            onTap: () {
              showDialog<String>(
                context: context,
                builder: (context) => _InputDialog('Type the IP'),
              );
            },
          ),
          ListTile(
            title: Text('Server port'),
            subtitle: Text('$serverPort'),
            onTap: () {
              showDialog<String>(
                context: context,
                builder: (context) => _InputDialog('Type the port'),
              );
            },
          ),
          CheckboxListTile(
            title: Text('Use Dark theme'),
            onChanged: (value) {
              setState(() {
                darkTheme = value;
              });
            },
            value: useHttps,
          ),
          CheckboxListTile(
            title: Text('Use HTTPS'),
            onChanged: (value) {
              setState(() {
                useHttps = value;
              });
            },
            value: useHttps,
          ),
          Divider(),
          CheckboxListTile(
            title: Text('Needs auth'),
            onChanged: (value) {
              setState(() {
                needsAuth = value;
              });
            },
            value: needsAuth,
          ),
          ListTile(
            enabled: needsAuth,
            title: Text('User ID'),
            subtitle: Text(userId),
            onTap: () {
              showDialog<String>(
                context: context,
                builder: (context) => _InputDialog('Type the username'),
              );
            },
          ),
          ListTile(
            enabled: needsAuth,
            title: Text('User password'),
            subtitle: Text(userPassword),
            onTap: () {
              showDialog<String>(
                context: context,
                builder: (context) => _InputDialog('Type the password'),
              );
            },
          ),
          Divider(),
          ListTile(
            title: Text('About OpenLP'),
            onTap: () {
              launch('https://openlp.org/');
            },
          ),
        ],
      ),
    );
  }
}

class _InputDialog extends StatelessWidget {
  final String title;

  _InputDialog(this.title);

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: Text(this.title),
      contentPadding: EdgeInsets.all(15),
      content: TextField(autofocus: true),
      actions: <Widget>[
        FlatButton(
          child: Text('CANCEL'),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        FlatButton(
          child: Text('OK'),
          onPressed: () {
            Navigator.pop(context, '');
          },
        ),
      ],
    );
  }
}
